# geordpy

<!-- add description here -->

## Installation

```bash
# production installation
$ pip install -r requirements.txt
$ pip install geordpy

# development installation
$ pip install -e .[dev]
$ pre-commit install
```

## Usage

```python
import geordpy
```